@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2003-2015 FreeIPMI Core Team
- * 
+ *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
@@ -13,7 +13,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- * 
+ *
  */
 
 #ifndef TOOL_CONFIG_FILE_COMMON_H
@@ -63,9 +63,15 @@
 #define CONFIG_FILE_MAX_SENSOR_RECORD_IDS           128
 #define CONFIG_FILE_MAX_SENSOR_TYPES                16
 #else /* !__CYGWIN__ */
+#if 0
 /* record id is 16 bits - 65536 */
 #define CONFIG_FILE_MAX_SENSOR_RECORD_IDS           65536
 #define CONFIG_FILE_MAX_SENSOR_TYPES                256
+#else  /* !0 */
+/* achu: pick more reasonable limits than the theoretical maxes */
+#define CONFIG_FILE_MAX_SENSOR_RECORD_IDS           4096
+#define CONFIG_FILE_MAX_SENSOR_TYPES                128
+#endif  /* !0 */
 #endif /* !__CYGWIN__ */
 #define CONFIG_FILE_MAX_SENSOR_TYPES_STRING_LENGTH  256
 
@@ -77,8 +83,8 @@ struct config_file_data_bmc_info
 
 struct config_file_data_bmc_watchdog
 {
-  char *logfile;		/* deprecated */
-  int logfile_count;		/* deprecated */
+  char *logfile;                /* deprecated */
+  int logfile_count;            /* deprecated */
   int verbose_logging;
   int verbose_logging_count;
   int no_logging;
@@ -101,8 +107,8 @@ struct config_file_data_ipmi_fru
 {
   unsigned int verbose_count;
   int verbose_count_count;
-  int skip_checks;		/* legacy - parse for backwards compatability */
-  int skip_checks_count;	/* legacy - parse for backwards compatability */
+  int skip_checks;              /* legacy - parse for backwards compatability */
+  int skip_checks_count;        /* legacy - parse for backwards compatability */
   int bridge_fru;
   int bridge_fru_count;
   int interpret_oem_data;
