@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2003-2015 FreeIPMI Core Team
- * 
+ *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
@@ -13,7 +13,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- * 
+ *
  */
 
 #if HAVE_CONFIG_H
@@ -56,9 +56,9 @@ _str_replace_char (char *str, char chr, char with)
 {
   char *p = NULL;
   char *s = NULL;
-  
+
   assert (str);
-  
+
   for (s = str;
        (p = strchr (s, chr));
        s = p + 1)
@@ -76,7 +76,7 @@ get_sensor_type_output_string (unsigned int sensor_type)
   return (UNRECOGNIZED_SENSOR_TYPE);
 }
 
-const char * 
+const char *
 get_oem_sensor_type_output_string (uint8_t sensor_type,
                                    uint8_t event_reading_code,
                                    uint32_t manufacturer_id,
@@ -89,7 +89,7 @@ get_oem_sensor_type_output_string (uint8_t sensor_type,
                                                           manufacturer_id,
                                                           product_id)))
     return (sensor_type_str);
-  
+
   return (UNRECOGNIZED_SENSOR_TYPE);
 }
 
@@ -116,18 +116,18 @@ _output_sensor_type (const char *sensor_type_str)
     }
 
   _get_sensor_type_cmdline_string (tmpstr);
-  
+
   printf ("%s\n", tmpstr);
-  
+
   free (tmpstr);
   return (0);
 }
 
 int
 parse_sensor_types (const char *special_string,
-		    char sensor_types[MAX_SENSOR_TYPES][MAX_SENSOR_TYPES_STRING_LENGTH+1],
-		    unsigned int *sensor_types_length,
-		    const char *arg)
+                    char sensor_types[MAX_SENSOR_TYPES][MAX_SENSOR_TYPES_STRING_LENGTH+1],
+                    unsigned int *sensor_types_length,
+                    const char *arg)
 {
   char *strtmp;
   char *tok;
@@ -147,13 +147,13 @@ parse_sensor_types (const char *special_string,
   while (tok && (*sensor_types_length) < MAX_SENSOR_TYPES)
     {
       if (!strcasecmp (tok, special_string))
-	{
-	  (*sensor_types_length) = 0;
-	  break;
-	}
+        {
+          (*sensor_types_length) = 0;
+          break;
+        }
       strncpy (sensor_types[(*sensor_types_length)],
-	       tok,
-	       MAX_SENSOR_TYPES_STRING_LENGTH);
+               tok,
+               MAX_SENSOR_TYPES_STRING_LENGTH);
       (*sensor_types_length)++;
       tok = strtok (NULL, " ,");
     }
@@ -174,10 +174,10 @@ list_sensor_types (void)
       if (_output_sensor_type (ipmi_sensor_types[i]) < 0)
         return (-1);
     }
-  
+
   if (_output_sensor_type (ipmi_oem_sensor_type) < 0)
     return (-1);
-  
+
   return (0);
 }
 
@@ -211,10 +211,10 @@ valid_sensor_types (char sensor_types[][MAX_SENSOR_TYPES_STRING_LENGTH+1],
           while (ipmi_sensor_types[j])
             {
               char sensor_type_cmdline[MAX_SENSOR_TYPES_STRING_LENGTH];
-              
+
               strcpy (sensor_type_cmdline, ipmi_sensor_types[j]);
               _get_sensor_type_cmdline_string (sensor_type_cmdline);
-              
+
               if (!strcasecmp (sensor_types[i], ipmi_sensor_types[j])
                   || !strcasecmp (sensor_types[i], sensor_type_cmdline))
                 {
@@ -224,24 +224,24 @@ valid_sensor_types (char sensor_types[][MAX_SENSOR_TYPES_STRING_LENGTH+1],
               j++;
             }
         }
-      
+
       if (!found)
-	{
-	  char sensor_type_cmdline[MAX_SENSOR_TYPES_STRING_LENGTH];
-          
-	  strcpy (sensor_type_cmdline, ipmi_oem_sensor_type);
-	  _get_sensor_type_cmdline_string (sensor_type_cmdline);
-              
-	  if (!strcasecmp (sensor_types[i], ipmi_oem_sensor_type)
-	      || !strcasecmp (sensor_types[i], sensor_type_cmdline))
-	    found++;
-	}
-      
+        {
+          char sensor_type_cmdline[MAX_SENSOR_TYPES_STRING_LENGTH];
+
+          strcpy (sensor_type_cmdline, ipmi_oem_sensor_type);
+          _get_sensor_type_cmdline_string (sensor_type_cmdline);
+
+          if (!strcasecmp (sensor_types[i], ipmi_oem_sensor_type)
+              || !strcasecmp (sensor_types[i], sensor_type_cmdline))
+            found++;
+        }
+
       if (!found)
         {
           fprintf (stderr,
-		   "invalid sensor type '%s'\n",
-		   sensor_types[i]);
+                   "invalid sensor type '%s'\n",
+                   sensor_types[i]);
           return (-1);
         }
     }
@@ -270,7 +270,7 @@ get_sensor_units_output_string (pstdout_state_t pstate,
 
   if (ipmi_sdr_parse_sensor_units (sdr_ctx,
                                    NULL,
-				   0,
+                                   0,
                                    &sensor_units_percentage,
                                    &sensor_units_modifier,
                                    &sensor_units_rate,
@@ -283,8 +283,7 @@ get_sensor_units_output_string (pstdout_state_t pstate,
                        ipmi_sdr_ctx_errormsg (sdr_ctx));
       goto cleanup;
     }
-  
-  memset (sensor_units_buf, '\0', sensor_units_buflen);
+
   sensor_units_ret = ipmi_sensor_units_string (sensor_units_percentage,
                                                sensor_units_modifier,
                                                sensor_units_rate,
@@ -293,13 +292,13 @@ get_sensor_units_output_string (pstdout_state_t pstate,
                                                sensor_units_buf,
                                                sensor_units_buflen,
                                                !non_abbreviated_units_flag);
-  
+
   if (sensor_units_ret <= 0)
     snprintf (sensor_units_buf,
               sensor_units_buflen,
               "%s",
               ipmi_sensor_units[IPMI_SENSOR_UNIT_UNSPECIFIED]);
-  
+
   rv = 0;
  cleanup:
   return rv;
@@ -317,7 +316,7 @@ _sensor_type_strcmp (pstdout_state_t pstate,
   char *ptr = NULL;
 
   assert (sensor_type_str_input);
-  
+
   errno = 0;
   value = strtol (sensor_type_str_input, &ptr, 0);
 
@@ -334,30 +333,30 @@ _sensor_type_strcmp (pstdout_state_t pstate,
 
   /* Don't use get_sensor_type_output_string() - want NULL if invalid */
   sensor_type_str = ipmi_get_sensor_type_string (sensor_type);
-  
+
   if (!sensor_type_str)
-    { 
+    {
       rv = 0;
       goto cleanup;
-    } 
-  
+    }
+
   if (!(tmpstr = strdup (sensor_type_str)))
-    { 
+    {
       PSTDOUT_FPRINTF (pstate,
                        stderr,
                        "strdup: %s\n",
                        strerror (errno));
       goto cleanup;
-    } 
-  
+    }
+
   _get_sensor_type_cmdline_string (tmpstr);
-  
+
   if (!strcasecmp (sensor_type_str_input, sensor_type_str)
       || !strcasecmp (sensor_type_str_input, tmpstr))
     rv = 1;
   else
     rv = 0;
-  
+
  cleanup:
   free (tmpstr);
   return (rv);
@@ -386,7 +385,7 @@ sensor_type_listed (pstdout_state_t pstate,
       if (ret)
         return (1);
     }
-  
+
   return (0);
 }
 
@@ -422,8 +421,8 @@ sensor_type_listed_sdr (pstdout_state_t pstate,
     return (0);
 
   if (ipmi_sdr_parse_sensor_type (sdr_ctx,
-				  NULL,
-				  0,
+                                  NULL,
+                                  0,
                                   &sensor_type) < 0)
     {
       PSTDOUT_FPRINTF (pstate,
@@ -470,11 +469,11 @@ _store_column_widths (pstdout_state_t pstate,
                       ipmi_sdr_ctx_t sdr_ctx,
                       uint8_t sensor_number,
                       unsigned int non_abbreviated_units,
-		      unsigned int shared_sensors,
+                      unsigned int shared_sensors,
                       unsigned int count_event_only_records,
                       unsigned int count_device_locator_records,
                       unsigned int count_oem_records,
-		      int entity_sensor_names,
+                      int entity_sensor_names,
                       struct sensor_column_width *column_width)
 {
   char sensor_name[IPMI_SDR_MAX_SENSOR_NAME_LENGTH + 1];
@@ -489,8 +488,8 @@ _store_column_widths (pstdout_state_t pstate,
   assert (column_width);
 
   if (ipmi_sdr_parse_record_id_and_type (sdr_ctx,
-					 NULL,
-					 0,
+                                         NULL,
+                                         0,
                                          &record_id,
                                          &record_type) < 0)
     {
@@ -507,7 +506,7 @@ _store_column_widths (pstdout_state_t pstate,
           || record_type != IPMI_SDR_FORMAT_EVENT_ONLY_RECORD)
       && (!count_device_locator_records
           || (record_type != IPMI_SDR_FORMAT_GENERIC_DEVICE_LOCATOR_RECORD
-	      && record_type != IPMI_SDR_FORMAT_FRU_DEVICE_LOCATOR_RECORD
+              && record_type != IPMI_SDR_FORMAT_FRU_DEVICE_LOCATOR_RECORD
               && record_type != IPMI_SDR_FORMAT_MANAGEMENT_CONTROLLER_DEVICE_LOCATOR_RECORD))
       && (!count_oem_records
           || record_type != IPMI_SDR_FORMAT_OEM_RECORD))
@@ -529,22 +528,22 @@ _store_column_widths (pstdout_state_t pstate,
   if (entity_sensor_names)
     {
       if (ipmi_sdr_parse_entity_sensor_name (sdr_ctx,
-					     NULL,
-					     0,
-					     sensor_number,
-					     !shared_sensors ? IPMI_SDR_SENSOR_NAME_FLAGS_IGNORE_SHARED_SENSORS : 0,
-					     sensor_name,
-					     IPMI_SDR_MAX_SENSOR_NAME_LENGTH) < 0)
-	{
-	  if (ipmi_sdr_ctx_errnum (sdr_ctx) == IPMI_SDR_ERR_PARSE_INVALID_SDR_RECORD)
-	    goto normal_sensor_name;
+                                             NULL,
+                                             0,
+                                             sensor_number,
+                                             !shared_sensors ? IPMI_SDR_SENSOR_NAME_FLAGS_IGNORE_SHARED_SENSORS : 0,
+                                             sensor_name,
+                                             IPMI_SDR_MAX_SENSOR_NAME_LENGTH) < 0)
+        {
+          if (ipmi_sdr_ctx_errnum (sdr_ctx) == IPMI_SDR_ERR_PARSE_INVALID_SDR_RECORD)
+            goto normal_sensor_name;
 
-	  PSTDOUT_FPRINTF (pstate,
-			   stderr,
-			   "ipmi_sdr_parse_entity_sensor_name: %s\n",
-			   ipmi_sdr_ctx_errormsg (sdr_ctx));
-	  return (-1);
-	}
+          PSTDOUT_FPRINTF (pstate,
+                           stderr,
+                           "ipmi_sdr_parse_entity_sensor_name: %s\n",
+                           ipmi_sdr_ctx_errormsg (sdr_ctx));
+          return (-1);
+        }
 
       len = strlen (sensor_name);
       if (len > column_width->sensor_name)
@@ -554,19 +553,19 @@ _store_column_widths (pstdout_state_t pstate,
     {
     normal_sensor_name:
       if (ipmi_sdr_parse_sensor_name (sdr_ctx,
-				      NULL,
-				      0,
-				      sensor_number,
-				      !shared_sensors ? IPMI_SDR_SENSOR_NAME_FLAGS_IGNORE_SHARED_SENSORS : 0,
-				      sensor_name,
-				      IPMI_SDR_MAX_SENSOR_NAME_LENGTH) < 0)
-	{
-	  PSTDOUT_FPRINTF (pstate,
-			   stderr,
-			   "ipmi_sdr_parse_sensor_name: %s\n",
-			   ipmi_sdr_ctx_errormsg (sdr_ctx));
-	  return (-1);
-	}
+                                      NULL,
+                                      0,
+                                      sensor_number,
+                                      !shared_sensors ? IPMI_SDR_SENSOR_NAME_FLAGS_IGNORE_SHARED_SENSORS : 0,
+                                      sensor_name,
+                                      IPMI_SDR_MAX_SENSOR_NAME_LENGTH) < 0)
+        {
+          PSTDOUT_FPRINTF (pstate,
+                           stderr,
+                           "ipmi_sdr_parse_sensor_name: %s\n",
+                           ipmi_sdr_ctx_errormsg (sdr_ctx));
+          return (-1);
+        }
 
       len = strlen (sensor_name);
       if (len > column_width->sensor_name)
@@ -578,8 +577,8 @@ _store_column_widths (pstdout_state_t pstate,
       || record_type == IPMI_SDR_FORMAT_EVENT_ONLY_RECORD)
     {
       if (ipmi_sdr_parse_sensor_type (sdr_ctx,
-				      NULL,
-				      0,
+                                      NULL,
+                                      0,
                                       &sensor_type) < 0)
         {
           PSTDOUT_FPRINTF (pstate,
@@ -594,8 +593,8 @@ _store_column_widths (pstdout_state_t pstate,
         column_width->sensor_type = len;
 
       if (ipmi_sdr_parse_event_reading_type_code (sdr_ctx,
-						  NULL,
-						  0,
+                                                  NULL,
+                                                  0,
                                                   &event_reading_type_code) < 0)
         {
           PSTDOUT_FPRINTF (pstate,
@@ -608,7 +607,7 @@ _store_column_widths (pstdout_state_t pstate,
       if (ipmi_event_reading_type_code_class (event_reading_type_code) == IPMI_EVENT_READING_TYPE_CODE_CLASS_THRESHOLD)
         {
           char sensor_units_buf[SENSOR_UNITS_BUFLEN + 1];
-          
+
           memset (sensor_units_buf, '\0', SENSOR_UNITS_BUFLEN + 1);
           if (get_sensor_units_output_string (pstate,
                                               sdr_ctx,
@@ -616,13 +615,13 @@ _store_column_widths (pstdout_state_t pstate,
                                               SENSOR_UNITS_BUFLEN,
                                               non_abbreviated_units) < 0)
             return (-1);
-          
+
           len = strlen (sensor_units_buf);
           if (len > column_width->sensor_units)
             column_width->sensor_units = len;
         }
     }
-  
+
   return (0);
 }
 
@@ -633,7 +632,7 @@ _store_column_widths_shared (pstdout_state_t pstate,
                              unsigned int count_event_only_records,
                              unsigned int count_device_locator_records,
                              unsigned int count_oem_records,
-			     int entity_sensor_names,
+                             int entity_sensor_names,
                              struct sensor_column_width *column_width)
 {
   uint8_t record_type;
@@ -645,8 +644,8 @@ _store_column_widths_shared (pstdout_state_t pstate,
   assert (column_width);
 
   if (ipmi_sdr_parse_record_id_and_type (sdr_ctx,
-					 NULL,
-					 0,
+                                         NULL,
+                                         0,
                                          NULL,
                                          &record_type) < 0)
     {
@@ -664,19 +663,19 @@ _store_column_widths_shared (pstdout_state_t pstate,
                                 sdr_ctx,
                                 0,
                                 non_abbreviated_units,
-				0, /* shared_sensors */
+                                0, /* shared_sensors */
                                 count_event_only_records,
                                 count_device_locator_records,
                                 count_oem_records,
-				entity_sensor_names,
+                                entity_sensor_names,
                                 column_width) < 0)
         return (-1);
       return (0);
     }
-  
+
   if (ipmi_sdr_parse_sensor_record_sharing (sdr_ctx,
-					    NULL,
-					    0,
+                                            NULL,
+                                            0,
                                             &share_count,
                                             NULL,
                                             NULL,
@@ -688,26 +687,26 @@ _store_column_widths_shared (pstdout_state_t pstate,
                        ipmi_sdr_ctx_errormsg (sdr_ctx));
       return (-1);
     }
-  
+
   if (share_count <= 1)
     {
       if (_store_column_widths (pstate,
                                 sdr_ctx,
                                 0,
                                 non_abbreviated_units,
-				0, /* shared_sensors */
+                                0, /* shared_sensors */
                                 count_event_only_records,
                                 count_device_locator_records,
                                 count_oem_records,
-				entity_sensor_names,
+                                entity_sensor_names,
                                 column_width) < 0)
         return (-1);
       return (0);
     }
 
   if (ipmi_sdr_parse_sensor_number (sdr_ctx,
-				    NULL,
-				    0,
+                                    NULL,
+                                    0,
                                     &sensor_number_base) < 0)
     {
       PSTDOUT_FPRINTF (pstate,
@@ -717,7 +716,7 @@ _store_column_widths_shared (pstdout_state_t pstate,
       return (-1);
     }
 
-  
+
   /* IPMI spec gives the following example:
    *
    * "If the starting sensor number was 10, and the share
@@ -727,18 +726,18 @@ _store_column_widths_shared (pstdout_state_t pstate,
   for (i = 0; i < share_count; i++)
     {
       uint8_t sensor_number;
-      
+
       sensor_number = sensor_number_base + i;
-      
+
       if (_store_column_widths (pstate,
                                 sdr_ctx,
                                 sensor_number,
                                 non_abbreviated_units,
-				1, /* shared_sensors */
+                                1, /* shared_sensors */
                                 count_event_only_records,
                                 count_device_locator_records,
                                 count_oem_records,
-				entity_sensor_names,
+                                entity_sensor_names,
                                 column_width) < 0)
         return (-1);
     }
@@ -758,7 +757,7 @@ calculate_column_widths (pstdout_state_t pstate,
                          unsigned int count_event_only_records,
                          unsigned int count_device_locator_records,
                          unsigned int count_oem_records,
-			 int entity_sensor_names,
+                         int entity_sensor_names,
                          struct sensor_column_width *column_width)
 {
   int rv = -1;
@@ -795,7 +794,7 @@ calculate_column_widths (pstdout_state_t pstate,
                                                count_event_only_records,
                                                count_device_locator_records,
                                                count_oem_records,
-					       entity_sensor_names,
+                                               entity_sensor_names,
                                                column_width) < 0)
                 goto cleanup;
             }
@@ -805,11 +804,11 @@ calculate_column_widths (pstdout_state_t pstate,
                                         sdr_ctx,
                                         0,
                                         non_abbreviated_units,
-					0, /* shared_sensors */
+                                        0, /* shared_sensors */
                                         count_event_only_records,
                                         count_device_locator_records,
                                         count_oem_records,
-					entity_sensor_names,
+                                        entity_sensor_names,
                                         column_width) < 0)
                 goto cleanup;
             }
@@ -853,7 +852,7 @@ calculate_column_widths (pstdout_state_t pstate,
                                                    count_event_only_records,
                                                    count_device_locator_records,
                                                    count_oem_records,
-						   entity_sensor_names,
+                                                   entity_sensor_names,
                                                    column_width) < 0)
                     goto cleanup;
                 }
@@ -863,11 +862,11 @@ calculate_column_widths (pstdout_state_t pstate,
                                             sdr_ctx,
                                             0,
                                             non_abbreviated_units,
-					    0, /* shared_sensors */
+                                            0, /* shared_sensors */
                                             count_event_only_records,
                                             count_device_locator_records,
                                             count_oem_records,
-					    entity_sensor_names,
+                                            entity_sensor_names,
                                             column_width) < 0)
                     goto cleanup;
                 }
@@ -884,7 +883,7 @@ calculate_column_widths (pstdout_state_t pstate,
 
 int
 calculate_column_widths_ignored_sdr_cache (unsigned int non_abbreviated_units,
-					   struct sensor_column_width *column_width)
+                                           struct sensor_column_width *column_width)
 {
   assert (column_width);
 
