@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2008-2015 FreeIPMI Core Team
- * 
+ *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
@@ -13,7 +13,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- * 
+ *
  */
 
 #if HAVE_CONFIG_H
@@ -73,9 +73,9 @@
  * 0x08 - network function
  * 0x02 - OEM cmd
  * 0x?? - task ID
- * 
+ *
  * Get Update Status Response
- *      
+ *
  * 0x08 - network function
  * 0x02 - OEM cmd
  * 0x?? - completion code
@@ -193,7 +193,7 @@ ipmi_oem_quanta_set_bmc_services (ipmi_oem_state_data_t *state_data)
 {
   assert (state_data);
   assert (state_data->prog_data->args->oem_options_count == 2);
-  
+
   return (ipmi_oem_thirdparty_set_bmc_services_v1 (state_data));
 }
 
@@ -473,7 +473,7 @@ ipmi_oem_quanta_get_processor_information (ipmi_oem_state_data_t *state_data)
    * 0x30 - OEM network function
    * 0x18 - OEM cmd
    * 0x?? - Processor Index, 1 based
-   * 
+   *
    * Response Get Processor Information
    *
    * 0x18 - OEM cmd
@@ -483,7 +483,7 @@ ipmi_oem_quanta_get_processor_information (ipmi_oem_state_data_t *state_data)
    */
 
   assert (state_data);
-  
+
   if (state_data->prog_data->args->oem_options_count > 1)
     {
       pstdout_fprintf (state_data->pstate,
@@ -512,7 +512,7 @@ ipmi_oem_quanta_get_processor_information (ipmi_oem_state_data_t *state_data)
                            state_data->prog_data->args->oem_options[0]);
           goto cleanup;
         }
-      
+
       processor_index_init = temp;
 
       processor_index_max = processor_index_init;
@@ -544,8 +544,8 @@ ipmi_oem_quanta_get_processor_information (ipmi_oem_state_data_t *state_data)
        * fall through to normal error output below.
        */
       if (rs_len >= 2
-	  && (bytes_rs[1] == IPMI_COMP_CODE_PARAMETER_OUT_OF_RANGE
-	      || bytes_rs[1] == IPMI_COMP_CODE_INVALID_DATA_FIELD_IN_REQUEST)
+          && (bytes_rs[1] == IPMI_COMP_CODE_PARAMETER_OUT_OF_RANGE
+              || bytes_rs[1] == IPMI_COMP_CODE_INVALID_DATA_FIELD_IN_REQUEST)
           && processor_index_init != processor_index_max
           && processor_index != 1)
         break;
@@ -564,69 +564,69 @@ ipmi_oem_quanta_get_processor_information (ipmi_oem_state_data_t *state_data)
       processor_mhz = (bytes_rs[3] | (bytes_rs[4] << 8));
 
       if (processor_type == IPMI_OEM_QUANTA_PROCESSOR_TYPE_NO_CPU_PRESENT)
-	pstdout_printf (state_data->pstate,
-			"Processor %u: No CPU Present\n",
+        pstdout_printf (state_data->pstate,
+                        "Processor %u: No CPU Present\n",
                         processor_index);
       else
-	{
-	  switch (processor_type)
-	    {
-	    case IPMI_OEM_QUANTA_PROCESSOR_TYPE_CELERON:
-	      processor_type_str = "Celeron";
-	      break;
-	    case IPMI_OEM_QUANTA_PROCESSOR_TYPE_PENTIUM_3:
-	      processor_type_str = "Pentium 3";
-	      break;
-	    case IPMI_OEM_QUANTA_PROCESSOR_TYPE_PENTIUM_4:
-	      processor_type_str = "Pentium 4";
-	      break;
-	    case IPMI_OEM_QUANTA_PROCESSOR_TYPE_XEON:
-	      processor_type_str = "Xeon";
-	      break;
-	    case IPMI_OEM_QUANTA_PROCESSOR_TYPE_PRESTONIA:
-	      processor_type_str = "Prestonia";
-	      break;
-	    case IPMI_OEM_QUANTA_PROCESSOR_TYPE_NOCONA:
-	      processor_type_str = "Nocona";
-	      break;
-	    case IPMI_OEM_QUANTA_PROCESSOR_TYPE_OPTERON:
-	      processor_type_str = "Opteron";
-	      break;
-	    case IPMI_OEM_QUANTA_PROCESSOR_TYPE_DEMPSEY:
-	      processor_type_str = "Dempsey";
-	      break;
-	    case IPMI_OEM_QUANTA_PROCESSOR_TYPE_CLOVERTOWN:
-	      processor_type_str = "Clovertown";
-	      break;
-	    case IPMI_OEM_QUANTA_PROCESSOR_TYPE_TIGERTON:
-	      processor_type_str = "Tigerton";
-	      break;
-	    case IPMI_OEM_QUANTA_PROCESSOR_TYPE_DUNNINGTON:
-	      processor_type_str = "Dunnington";
-	      break;
-	    case IPMI_OEM_QUANTA_PROCESSOR_TYPE_HARPERTOWN:
-	      processor_type_str = "Harpertown";
-	      break;
-	    case IPMI_OEM_QUANTA_PROCESSOR_TYPE_WOLFDALE_DP:
-	      /* achu: listed as "WolfDale-Dp" in spec, I don't like that output */
-	      processor_type_str = "Wolfdale-DP";
-	      break;
-	    case IPMI_OEM_QUANTA_PROCESSOR_TYPE_NEHALEM_EP:
-	      processor_type_str = "Nehalem-EP";
-	      break;
-	    case IPMI_OEM_QUANTA_PROCESSOR_TYPE_WESTMERE_EP:
-	      processor_type_str = "Westmere-EP";
-	      break;
-	    default:
-	      processor_type_str = "Unknown Processor";
-	    }
-	  
-	  pstdout_printf (state_data->pstate,
-			  "Processor %u: %s %.2f Ghz\n",
-			  processor_index,
-			  processor_type_str,
-			  (double)processor_mhz / 1000);
-	}
+        {
+          switch (processor_type)
+            {
+            case IPMI_OEM_QUANTA_PROCESSOR_TYPE_CELERON:
+              processor_type_str = "Celeron";
+              break;
+            case IPMI_OEM_QUANTA_PROCESSOR_TYPE_PENTIUM_3:
+              processor_type_str = "Pentium 3";
+              break;
+            case IPMI_OEM_QUANTA_PROCESSOR_TYPE_PENTIUM_4:
+              processor_type_str = "Pentium 4";
+              break;
+            case IPMI_OEM_QUANTA_PROCESSOR_TYPE_XEON:
+              processor_type_str = "Xeon";
+              break;
+            case IPMI_OEM_QUANTA_PROCESSOR_TYPE_PRESTONIA:
+              processor_type_str = "Prestonia";
+              break;
+            case IPMI_OEM_QUANTA_PROCESSOR_TYPE_NOCONA:
+              processor_type_str = "Nocona";
+              break;
+            case IPMI_OEM_QUANTA_PROCESSOR_TYPE_OPTERON:
+              processor_type_str = "Opteron";
+              break;
+            case IPMI_OEM_QUANTA_PROCESSOR_TYPE_DEMPSEY:
+              processor_type_str = "Dempsey";
+              break;
+            case IPMI_OEM_QUANTA_PROCESSOR_TYPE_CLOVERTOWN:
+              processor_type_str = "Clovertown";
+              break;
+            case IPMI_OEM_QUANTA_PROCESSOR_TYPE_TIGERTON:
+              processor_type_str = "Tigerton";
+              break;
+            case IPMI_OEM_QUANTA_PROCESSOR_TYPE_DUNNINGTON:
+              processor_type_str = "Dunnington";
+              break;
+            case IPMI_OEM_QUANTA_PROCESSOR_TYPE_HARPERTOWN:
+              processor_type_str = "Harpertown";
+              break;
+            case IPMI_OEM_QUANTA_PROCESSOR_TYPE_WOLFDALE_DP:
+              /* achu: listed as "WolfDale-Dp" in spec, I don't like that output */
+              processor_type_str = "Wolfdale-DP";
+              break;
+            case IPMI_OEM_QUANTA_PROCESSOR_TYPE_NEHALEM_EP:
+              processor_type_str = "Nehalem-EP";
+              break;
+            case IPMI_OEM_QUANTA_PROCESSOR_TYPE_WESTMERE_EP:
+              processor_type_str = "Westmere-EP";
+              break;
+            default:
+              processor_type_str = "Unknown Processor";
+            }
+
+          pstdout_printf (state_data->pstate,
+                          "Processor %u: %s %.2f Ghz\n",
+                          processor_index,
+                          processor_type_str,
+                          (double)processor_mhz / 1000);
+        }
     }
 
   rv = 0;
@@ -666,7 +666,7 @@ _ipmi_oem_quanta_read_mac_address_s99q (ipmi_oem_state_data_t *state_data)
    * byte 2 = 0xAA (slave address 7 bit = 0x55, lowest bit for r/w, 0b = read, 1b = write)
    * byte 3 = 0x0C - read count
    * byte 4/5 - 0x0000 - address to read, msb first
-   * 
+   *
    * response
    *
    * byte 1 = comp-code
@@ -683,15 +683,6 @@ _ipmi_oem_quanta_read_mac_address_s99q (ipmi_oem_state_data_t *state_data)
       goto cleanup;
     }
 
-  if (fiid_obj_clear (obj_cmd_rs) < 0)
-    {
-      pstdout_fprintf (state_data->pstate,
-                       stderr,
-                       "fiid_obj_clear: %s\n",
-                       fiid_obj_errormsg (obj_cmd_rs));
-      goto cleanup;
-    }
-
   data_rq[0] = (IPMI_OEM_QUANTA_MAC_ADDRESS_BASE_OFFSET & 0xFF00) >> 8;
   data_rq[1] = (IPMI_OEM_QUANTA_MAC_ADDRESS_BASE_OFFSET & 0x00FF);
 
@@ -766,7 +757,7 @@ ipmi_oem_quanta_read_mac_address (ipmi_oem_state_data_t *state_data)
 
   if (!strcasecmp (state_data->prog_data->args->oem_options[0], "s99q"))
     return _ipmi_oem_quanta_read_mac_address_s99q (state_data);
-  
+
   pstdout_fprintf (state_data->pstate,
                    stderr,
                    "%s:%s invalid OEM option argument '%s'\n",
@@ -798,7 +789,7 @@ _ipmi_oem_quanta_write_mac_address_s99q (ipmi_oem_state_data_t *state_data)
                        state_data->prog_data->args->oem_options[1]);
       goto cleanup;
     }
-  
+
   if (sscanf (state_data->prog_data->args->oem_options[2],
               "%02x:%02x:%02x:%02x:%02x:%02x",
               &b1,
@@ -827,7 +818,7 @@ _ipmi_oem_quanta_write_mac_address_s99q (ipmi_oem_state_data_t *state_data)
    * byte 4/5 - 0x0000 | 0x0006 - address to read, msb first
    *          - 0x0000 for dedicated
    *          - 0x0006 for shared
-   * 
+   *
    * response
    *
    * byte 1 = comp-code
@@ -842,15 +833,6 @@ _ipmi_oem_quanta_write_mac_address_s99q (ipmi_oem_state_data_t *state_data)
       goto cleanup;
     }
 
-  if (fiid_obj_clear (obj_cmd_rs) < 0)
-    {
-      pstdout_fprintf (state_data->pstate,
-                       stderr,
-                       "fiid_obj_clear: %s\n",
-                       fiid_obj_errormsg (obj_cmd_rs));
-      goto cleanup;
-    }
-
   if (!strcasecmp (state_data->prog_data->args->oem_options[1], "dedicated"))
     {
       data_rq[0] = (IPMI_OEM_QUANTA_MAC_ADDRESS_DEDICATED_OFFSET & 0xFF00) >> 8;
@@ -900,7 +882,7 @@ ipmi_oem_quanta_write_mac_address (ipmi_oem_state_data_t *state_data)
 
   if (!strcasecmp (state_data->prog_data->args->oem_options[0], "s99q"))
     return _ipmi_oem_quanta_write_mac_address_s99q (state_data);
-  
+
   pstdout_fprintf (state_data->pstate,
                    stderr,
                    "%s:%s invalid OEM option argument '%s'\n",
