@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2003-2015 FreeIPMI Core Team
- * 
+ *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
@@ -13,7 +13,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- * 
+ *
  */
 
 #ifdef HAVE_CONFIG_H
@@ -80,15 +80,15 @@ fiid_template_t tmpl_kcs_raw =
 
 static void
 _api_kcs_dump (ipmi_ctx_t ctx,
-	       const void *pkt,
-	       unsigned int pkt_len,
-	       uint8_t cmd,
-	       uint8_t net_fn,
-	       uint8_t group_extension,
-	       unsigned int debug_direction,
-	       fiid_template_t tmpl_cmd,
-	       fiid_template_t tmpl_ipmb_msg_hdr,
-	       fiid_template_t tmpl_ipmb_cmd)
+               const void *pkt,
+               unsigned int pkt_len,
+               uint8_t cmd,
+               uint8_t net_fn,
+               uint8_t group_extension,
+               unsigned int debug_direction,
+               fiid_template_t tmpl_cmd,
+               fiid_template_t tmpl_ipmb_msg_hdr,
+               fiid_template_t tmpl_ipmb_cmd)
 {
   char hdrbuf[DEBUG_UTIL_HDR_BUFLEN];
 
@@ -107,7 +107,7 @@ _api_kcs_dump (ipmi_ctx_t ctx,
                  debug_direction,
                  net_fn,
                  cmd,
-		 group_extension,
+                 group_extension,
                  hdrbuf,
                  DEBUG_UTIL_HDR_BUFLEN);
 
@@ -138,63 +138,63 @@ _api_kcs_dump (ipmi_ctx_t ctx,
 
 static void
 _api_kcs_dump_rq (ipmi_ctx_t ctx,
-		  const void *pkt,
-		  unsigned int pkt_len,
-		  uint8_t cmd,
-		  uint8_t net_fn,
-		  uint8_t group_extension,
-		  fiid_obj_t obj_cmd_rq)
+                  const void *pkt,
+                  unsigned int pkt_len,
+                  uint8_t cmd,
+                  uint8_t net_fn,
+                  uint8_t group_extension,
+                  fiid_obj_t obj_cmd_rq)
 {
   fiid_field_t *tmpl_cmd = NULL;
 
   if ((tmpl_cmd = fiid_obj_template (obj_cmd_rq)))
     {
       _api_kcs_dump (ctx,
-		     pkt,
-		     pkt_len,
-		     cmd,
-		     net_fn,
-		     group_extension,
-		     DEBUG_UTIL_DIRECTION_REQUEST,
-		     tmpl_cmd,
-		     tmpl_ipmb_msg_hdr_rq,
-		     ctx->tmpl_ipmb_cmd_rq);
+                     pkt,
+                     pkt_len,
+                     cmd,
+                     net_fn,
+                     group_extension,
+                     DEBUG_UTIL_DIRECTION_REQUEST,
+                     tmpl_cmd,
+                     tmpl_ipmb_msg_hdr_rq,
+                     ctx->tmpl_ipmb_cmd_rq);
       fiid_template_free (tmpl_cmd);
     }
 }
 
 static void
 _api_kcs_dump_rs (ipmi_ctx_t ctx,
-		  const void *pkt,
-		  unsigned int pkt_len,
-		  uint8_t cmd,
-		  uint8_t net_fn,
-		  uint8_t group_extension,
-		  fiid_obj_t obj_cmd_rs)
+                  const void *pkt,
+                  unsigned int pkt_len,
+                  uint8_t cmd,
+                  uint8_t net_fn,
+                  uint8_t group_extension,
+                  fiid_obj_t obj_cmd_rs)
 {
   fiid_field_t *tmpl_cmd = NULL;
 
   if ((tmpl_cmd = fiid_obj_template (obj_cmd_rs)))
     {
       _api_kcs_dump (ctx,
-		     pkt,
-		     pkt_len,
-		     cmd,
-		     net_fn,
-		     group_extension,
-		     DEBUG_UTIL_DIRECTION_RESPONSE,
-		     tmpl_cmd,
-		     tmpl_ipmb_msg_hdr_rs,
-		     ctx->tmpl_ipmb_cmd_rs);
+                     pkt,
+                     pkt_len,
+                     cmd,
+                     net_fn,
+                     group_extension,
+                     DEBUG_UTIL_DIRECTION_RESPONSE,
+                     tmpl_cmd,
+                     tmpl_ipmb_msg_hdr_rs,
+                     ctx->tmpl_ipmb_cmd_rs);
       fiid_template_free (tmpl_cmd);
     }
 }
 
 static int
 _kcs_cmd_write (ipmi_ctx_t ctx,
-		uint8_t cmd,
-		uint8_t group_extension,
-		fiid_obj_t obj_cmd_rq)
+                uint8_t cmd,
+                uint8_t group_extension,
+                fiid_obj_t obj_cmd_rq)
 {
   uint8_t *pkt = NULL;
   unsigned int pkt_len;
@@ -209,21 +209,20 @@ _kcs_cmd_write (ipmi_ctx_t ctx,
       API_ERRNO_TO_API_ERRNUM (ctx, errno);
       goto cleanup;
     }
-  
+
   if ((cmd_len = fiid_obj_len_bytes (obj_cmd_rq)) < 0)
     {
       API_FIID_OBJECT_ERROR_TO_API_ERRNUM (ctx, obj_cmd_rq);
       goto cleanup;
     }
-  
+
   pkt_len = hdr_len + cmd_len;
-    
+
   if (!(pkt = malloc (pkt_len)))
     {
       API_ERRNO_TO_API_ERRNUM (ctx, errno);
       goto cleanup;
     }
-  memset (pkt, '\0', pkt_len);
 
   if (fill_hdr_ipmi_kcs (ctx->target.lun,
                          ctx->target.net_fn,
@@ -232,26 +231,26 @@ _kcs_cmd_write (ipmi_ctx_t ctx,
       API_ERRNO_TO_API_ERRNUM (ctx, errno);
       goto cleanup;
     }
-  
+
   if ((send_len = assemble_ipmi_kcs_pkt (ctx->io.inband.rq.obj_hdr,
                                          obj_cmd_rq,
                                          pkt,
                                          pkt_len,
-					 IPMI_INTERFACE_FLAGS_DEFAULT)) < 0)
+                                         IPMI_INTERFACE_FLAGS_DEFAULT)) < 0)
     {
       API_ERRNO_TO_API_ERRNUM (ctx, errno);
       goto cleanup;
     }
-  
+
   if (ctx->flags & IPMI_FLAGS_DEBUG_DUMP && send_len)
     _api_kcs_dump_rq (ctx,
-		      pkt,
-		      send_len,
-		      cmd,
-		      ctx->target.net_fn,
-		      group_extension,
-		      obj_cmd_rq);
-  
+                      pkt,
+                      send_len,
+                      cmd,
+                      ctx->target.net_fn,
+                      group_extension,
+                      obj_cmd_rq);
+
   if (ipmi_kcs_write (ctx->io.inband.kcs_ctx, pkt, send_len) < 0)
     {
       API_KCS_ERRNUM_TO_API_ERRNUM (ctx, ipmi_kcs_ctx_errnum (ctx->io.inband.kcs_ctx));
@@ -266,9 +265,9 @@ _kcs_cmd_write (ipmi_ctx_t ctx,
 
 static int
 _kcs_cmd_read (ipmi_ctx_t ctx,
-	       uint8_t cmd,
-	       uint8_t group_extension,
-	       fiid_obj_t obj_cmd_rs)
+               uint8_t cmd,
+               uint8_t group_extension,
+               fiid_obj_t obj_cmd_rs)
 {
   uint8_t *pkt = NULL;
   unsigned int pkt_len;
@@ -303,15 +302,13 @@ _kcs_cmd_read (ipmi_ctx_t ctx,
     }
 
   pkt_len = hdr_len + cmd_len;
-  
+
   if (!(pkt = malloc (pkt_len)))
     {
       API_ERRNO_TO_API_ERRNUM (ctx, errno);
       goto cleanup;
     }
 
-  memset (pkt, '\0', pkt_len);
-
   if ((read_len = ipmi_kcs_read (ctx->io.inband.kcs_ctx,
                                  pkt,
                                  pkt_len)) < 0)
@@ -319,27 +316,27 @@ _kcs_cmd_read (ipmi_ctx_t ctx,
       API_KCS_ERRNUM_TO_API_ERRNUM (ctx, ipmi_kcs_ctx_errnum (ctx->io.inband.kcs_ctx));
       goto cleanup;
     }
-  
+
   if (!read_len)
     {
       API_SET_ERRNUM (ctx, IPMI_ERR_SYSTEM_ERROR);
       goto cleanup;
     }
-  
+
   if (ctx->flags & IPMI_FLAGS_DEBUG_DUMP && read_len)
     _api_kcs_dump_rs (ctx,
-		      pkt,
-		      read_len,
-		      cmd,
-		      ctx->target.net_fn,
-		      group_extension,
-		      obj_cmd_rs);
-  
+                      pkt,
+                      read_len,
+                      cmd,
+                      ctx->target.net_fn,
+                      group_extension,
+                      obj_cmd_rs);
+
   if ((ret = unassemble_ipmi_kcs_pkt (pkt,
                                       read_len,
                                       ctx->io.inband.rs.obj_hdr,
                                       obj_cmd_rs,
-				      intf_flags)) < 0)
+                                      intf_flags)) < 0)
     {
       API_ERRNO_TO_API_ERRNUM (ctx, errno);
       goto cleanup;
@@ -351,7 +348,7 @@ _kcs_cmd_read (ipmi_ctx_t ctx,
       API_SET_ERRNUM (ctx, IPMI_ERR_IPMI_ERROR);
       goto cleanup;
     }
-  
+
   rv = 0;
  cleanup:
   free (pkt);
@@ -361,20 +358,20 @@ _kcs_cmd_read (ipmi_ctx_t ctx,
 
 int
 api_kcs_cmd (ipmi_ctx_t ctx,
-	     fiid_obj_t obj_cmd_rq,
-	     fiid_obj_t obj_cmd_rs)
+             fiid_obj_t obj_cmd_rq,
+             fiid_obj_t obj_cmd_rs)
 {
   uint8_t cmd = 0;             /* used for debugging */
   uint8_t group_extension = 0; /* used for debugging */
   uint64_t val;
 
   assert (ctx
-	  && ctx->magic == IPMI_CTX_MAGIC
-	  && ctx->type == IPMI_DEVICE_KCS
-	  && fiid_obj_valid (obj_cmd_rq)
-	  && fiid_obj_packet_valid (obj_cmd_rq) == 1
-	  && fiid_obj_valid (obj_cmd_rs));
-  
+          && ctx->magic == IPMI_CTX_MAGIC
+          && ctx->type == IPMI_DEVICE_KCS
+          && fiid_obj_valid (obj_cmd_rq)
+          && fiid_obj_packet_valid (obj_cmd_rq) == 1
+          && fiid_obj_valid (obj_cmd_rs));
+
   if (ctx->flags & IPMI_FLAGS_DEBUG_DUMP)
     {
       /* ignore error, continue on */
@@ -384,15 +381,15 @@ api_kcs_cmd (ipmi_ctx_t ctx,
         cmd = val;
 
       if (IPMI_NET_FN_GROUP_EXTENSION (ctx->target.net_fn))
-	{
-	  /* ignore error, continue on */
-	  if (FIID_OBJ_GET (obj_cmd_rq,
-			    "group_extension_identification",
-			    &val) < 0)
-	    API_FIID_OBJECT_ERROR_TO_API_ERRNUM (ctx, obj_cmd_rq);
-	  else
-	    group_extension = val;
-	}
+        {
+          /* ignore error, continue on */
+          if (FIID_OBJ_GET (obj_cmd_rq,
+                            "group_extension_identification",
+                            &val) < 0)
+            API_FIID_OBJECT_ERROR_TO_API_ERRNUM (ctx, obj_cmd_rq);
+          else
+            group_extension = val;
+        }
     }
 
   if (_kcs_cmd_write (ctx, cmd, group_extension, obj_cmd_rq) < 0)
@@ -406,7 +403,7 @@ api_kcs_cmd (ipmi_ctx_t ctx,
 
 static int
 _api_kcs_ipmb_send (ipmi_ctx_t ctx,
-		    fiid_obj_t obj_cmd_rq)
+                    fiid_obj_t obj_cmd_rq)
 {
   struct ipmi_ctx_target target_save;
   uint8_t buf[IPMI_MAX_PKT_LEN];
@@ -452,13 +449,12 @@ _api_kcs_ipmb_send (ipmi_ctx_t ctx,
   if (assemble_ipmi_ipmb_msg (obj_ipmb_msg_hdr_rq,
                               obj_cmd_rq,
                               obj_ipmb_msg_rq,
-			      IPMI_INTERFACE_FLAGS_DEFAULT) < 0)
+                              IPMI_INTERFACE_FLAGS_DEFAULT) < 0)
     {
       API_ERRNO_TO_API_ERRNUM (ctx, errno);
       goto cleanup;
     }
 
-  memset (buf, '\0', IPMI_MAX_PKT_LEN);
   if ((len = fiid_obj_get_all (obj_ipmb_msg_rq,
                                buf,
                                IPMI_MAX_PKT_LEN)) < 0)
@@ -471,15 +467,15 @@ _api_kcs_ipmb_send (ipmi_ctx_t ctx,
   memcpy (&target_save, &ctx->target, sizeof (target_save));
   ctx->target.channel_number_is_set = 0;
   ctx->target.rs_addr_is_set = 0;
-  
+
   ret = ipmi_cmd_send_message (ctx,
-			       target_save.channel_number,
-			       IPMI_SEND_MESSAGE_AUTHENTICATION_NOT_REQUIRED,
-			       IPMI_SEND_MESSAGE_ENCRYPTION_NOT_REQUIRED,
-			       IPMI_SEND_MESSAGE_TRACKING_OPERATION_NO_TRACKING,
-			       buf,
-			       len,
-			       obj_send_cmd_rs);
+                               target_save.channel_number,
+                               IPMI_SEND_MESSAGE_AUTHENTICATION_NOT_REQUIRED,
+                               IPMI_SEND_MESSAGE_ENCRYPTION_NOT_REQUIRED,
+                               IPMI_SEND_MESSAGE_TRACKING_OPERATION_NO_TRACKING,
+                               buf,
+                               len,
+                               obj_send_cmd_rs);
 
   /* restore target info */
   memcpy (&ctx->target, &target_save, sizeof (target_save));
@@ -506,9 +502,9 @@ _api_kcs_ipmb_send (ipmi_ctx_t ctx,
 
 static int
 _api_kcs_ipmb_recv (ipmi_ctx_t ctx,
-		    fiid_obj_t obj_ipmb_msg_hdr_rs,
-		    fiid_obj_t obj_ipmb_msg_trlr,
-		    fiid_obj_t obj_cmd_rs)
+                    fiid_obj_t obj_ipmb_msg_hdr_rs,
+                    fiid_obj_t obj_ipmb_msg_trlr,
+                    fiid_obj_t obj_cmd_rs)
 {
   struct ipmi_ctx_target target_save;
   uint8_t buf[IPMI_MAX_PKT_LEN];
@@ -537,12 +533,12 @@ _api_kcs_ipmb_recv (ipmi_ctx_t ctx,
       API_ERRNO_TO_API_ERRNUM (ctx, errno);
       goto cleanup;
     }
-  
+
   /* get_message will send to the BMC, so clear out target information */
   memcpy (&target_save, &ctx->target, sizeof (target_save));
   ctx->target.channel_number_is_set = 0;
   ctx->target.rs_addr_is_set = 0;
-  
+
   ret = ipmi_cmd_get_message (ctx, obj_get_cmd_rs);
 
   /* restore target info */
@@ -578,7 +574,7 @@ _api_kcs_ipmb_recv (ipmi_ctx_t ctx,
                                 obj_ipmb_msg_hdr_rs,
                                 obj_cmd_rs,
                                 obj_ipmb_msg_trlr,
-				intf_flags) < 0)
+                                intf_flags) < 0)
     {
       API_ERRNO_TO_API_ERRNUM (ctx, errno);
       goto cleanup;
@@ -593,8 +589,8 @@ _api_kcs_ipmb_recv (ipmi_ctx_t ctx,
 
 int
 api_kcs_cmd_ipmb (ipmi_ctx_t ctx,
-		  fiid_obj_t obj_cmd_rq,
-		  fiid_obj_t obj_cmd_rs)
+                  fiid_obj_t obj_cmd_rq,
+                  fiid_obj_t obj_cmd_rs)
 {
   fiid_obj_t obj_ipmb_msg_hdr_rs = NULL;
   fiid_obj_t obj_ipmb_msg_trlr = NULL;
@@ -603,11 +599,11 @@ api_kcs_cmd_ipmb (ipmi_ctx_t ctx,
   int ret, rv = -1;
 
   assert (ctx
-	  && ctx->magic == IPMI_CTX_MAGIC
-	  && ctx->type == IPMI_DEVICE_KCS
-	  && fiid_obj_valid (obj_cmd_rq)
-	  && fiid_obj_packet_valid (obj_cmd_rq) == 1
-	  && fiid_obj_valid (obj_cmd_rs));
+          && ctx->magic == IPMI_CTX_MAGIC
+          && ctx->type == IPMI_DEVICE_KCS
+          && fiid_obj_valid (obj_cmd_rq)
+          && fiid_obj_packet_valid (obj_cmd_rq) == 1
+          && fiid_obj_valid (obj_cmd_rs));
 
   if (!(obj_ipmb_msg_hdr_rs = fiid_obj_create (tmpl_ipmb_msg_hdr_rs)))
     {
@@ -630,9 +626,9 @@ api_kcs_cmd_ipmb (ipmi_ctx_t ctx,
   while (1)
     {
       if (_api_kcs_ipmb_recv (ctx,
-			      obj_ipmb_msg_hdr_rs,
-			      obj_ipmb_msg_trlr,
-			      obj_cmd_rs) < 0)
+                              obj_ipmb_msg_hdr_rs,
+                              obj_ipmb_msg_trlr,
+                              obj_cmd_rs) < 0)
         {
           if (ctx->errnum == IPMI_ERR_MESSAGE_TIMEOUT)
             {
@@ -644,12 +640,12 @@ api_kcs_cmd_ipmb (ipmi_ctx_t ctx,
                   goto cleanup;
                 }
 
-	      /* Wait a little bit to avoid spinning and killing the
-	       * controller.  Observed on the Quanta QSSC-S4R/Appro
-	       * GB812X-CN that when bridging FRU reads, this allowed
-	       * records to be read more successfully.
-	       */
-	      usleep (IPMI_KCS_IPMB_REREAD_WAIT);
+              /* Wait a little bit to avoid spinning and killing the
+               * controller.  Observed on the Quanta QSSC-S4R/Appro
+               * GB812X-CN that when bridging FRU reads, this allowed
+               * records to be read more successfully.
+               */
+              usleep (IPMI_KCS_IPMB_REREAD_WAIT);
               continue;
             }
           goto cleanup;
@@ -711,22 +707,22 @@ api_kcs_cmd_ipmb (ipmi_ctx_t ctx,
 
 int
 api_kcs_cmd_raw (ipmi_ctx_t ctx,
-		 const void *buf_rq,
-		 unsigned int buf_rq_len,
-		 void *buf_rs,
-		 unsigned int buf_rs_len)
+                 const void *buf_rq,
+                 unsigned int buf_rq_len,
+                 void *buf_rs,
+                 unsigned int buf_rs_len)
 {
   fiid_obj_t obj_cmd_rq = NULL;
   fiid_obj_t obj_cmd_rs = NULL;
   int len, rv = -1;
 
   assert (ctx
-	  && ctx->magic == IPMI_CTX_MAGIC
-	  && ctx->type == IPMI_DEVICE_KCS
-	  && buf_rq
-	  && buf_rq_len
-	  && buf_rs
-	  && buf_rs_len);
+          && ctx->magic == IPMI_CTX_MAGIC
+          && ctx->type == IPMI_DEVICE_KCS
+          && buf_rq
+          && buf_rq_len
+          && buf_rs
+          && buf_rs_len);
 
   if (!(obj_cmd_rq = fiid_obj_create (tmpl_kcs_raw)))
     {
@@ -748,10 +744,10 @@ api_kcs_cmd_raw (ipmi_ctx_t ctx,
     }
 
   if (api_kcs_cmd (ctx,
-		   obj_cmd_rq,
-		   obj_cmd_rs) < 0)
+                   obj_cmd_rq,
+                   obj_cmd_rs) < 0)
     goto cleanup;
-  
+
   if ((len = fiid_obj_get_all (obj_cmd_rs,
                                buf_rs,
                                buf_rs_len)) < 0)
@@ -759,7 +755,7 @@ api_kcs_cmd_raw (ipmi_ctx_t ctx,
       API_FIID_OBJECT_ERROR_TO_API_ERRNUM (ctx, obj_cmd_rs);
       goto cleanup;
     }
-  
+
   rv = len;
  cleanup:
   fiid_obj_destroy (obj_cmd_rq);
@@ -769,22 +765,22 @@ api_kcs_cmd_raw (ipmi_ctx_t ctx,
 
 int
 api_kcs_cmd_raw_ipmb (ipmi_ctx_t ctx,
-		      const void *buf_rq,
-		      unsigned int buf_rq_len,
-		      void *buf_rs,
-		      unsigned int buf_rs_len)
+                      const void *buf_rq,
+                      unsigned int buf_rq_len,
+                      void *buf_rs,
+                      unsigned int buf_rs_len)
 {
   fiid_obj_t obj_cmd_rq = NULL;
   fiid_obj_t obj_cmd_rs = NULL;
   int len, rv = -1;
 
   assert (ctx
-	  && ctx->magic == IPMI_CTX_MAGIC
-	  && ctx->type == IPMI_DEVICE_KCS
-	  && buf_rq
-	  && buf_rq_len
-	  && buf_rs
-	  && buf_rs_len);
+          && ctx->magic == IPMI_CTX_MAGIC
+          && ctx->type == IPMI_DEVICE_KCS
+          && buf_rq
+          && buf_rq_len
+          && buf_rs
+          && buf_rs_len);
 
   if (!(obj_cmd_rq = fiid_obj_create (tmpl_kcs_raw)))
     {
@@ -806,10 +802,10 @@ api_kcs_cmd_raw_ipmb (ipmi_ctx_t ctx,
     }
 
   if (api_kcs_cmd_ipmb (ctx,
-			obj_cmd_rq,
-			obj_cmd_rs) < 0)
+                        obj_cmd_rq,
+                        obj_cmd_rs) < 0)
     goto cleanup;
-  
+
   if ((len = fiid_obj_get_all (obj_cmd_rs,
                                buf_rs,
                                buf_rs_len)) < 0)
@@ -817,7 +813,7 @@ api_kcs_cmd_raw_ipmb (ipmi_ctx_t ctx,
       API_FIID_OBJECT_ERROR_TO_API_ERRNUM (ctx, obj_cmd_rs);
       goto cleanup;
     }
-  
+
   rv = len;
  cleanup:
   fiid_obj_destroy (obj_cmd_rq);
