@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2003-2015 FreeIPMI Core Team
- * 
+ *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
@@ -13,7 +13,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- * 
+ *
  */
 
 #ifdef HAVE_CONFIG_H
@@ -269,13 +269,17 @@ ipmi_kcs_ctx_create (void)
       ERRNO_TRACE (errno);
       return (NULL);
     }
-  memset (ctx, '\0', sizeof (struct ipmi_kcs_ctx));
 
   ctx->magic = IPMI_KCS_CTX_MAGIC;
   ctx->driver_address = IPMI_KCS_SMS_IO_BASE_DEFAULT;
   ctx->register_spacing = IPMI_KCS_SMS_REGISTER_SPACING_DEFAULT;
   ctx->flags = IPMI_KCS_FLAGS_DEFAULT;
   ctx->poll_interval = IPMI_KCS_SLEEP_USECS;
+#ifdef __FreeBSD__
+#ifndef USE_IOPERM
+  ctx->dev_fd = -1;
+#endif
+#endif /* __FreeBSD__ */
   ctx->io_init = 0;
 
   if ((ctx->semid = driver_mutex_init ()) < 0)
@@ -549,7 +553,7 @@ _ipmi_kcs_timeval_diff (struct timeval *start, struct timeval *end)
       t += (IPMI_KCS_MICROSECONDS_IN_SECOND - start->tv_usec);
       t += end->tv_usec;
     }
-  
+
   return (t);
 }
 
@@ -572,21 +576,21 @@ _ipmi_kcs_spin_sleep (ipmi_kcs_ctx_t ctx)
       KCS_SET_ERRNUM (ctx, IPMI_KCS_ERR_SYSTEM_ERROR);
       return (-1);
     }
-  
+
   while (1)
     {
       unsigned long t;
-      
+
       if (gettimeofday (&spinend, NULL) < 0)
-	{
-	  KCS_SET_ERRNUM (ctx, IPMI_KCS_ERR_SYSTEM_ERROR);
-	  return (-1);
-	}
+        {
+          KCS_SET_ERRNUM (ctx, IPMI_KCS_ERR_SYSTEM_ERROR);
+          return (-1);
+        }
 
       t = _ipmi_kcs_timeval_diff (&spinstart, &spinend);
 
       if (t > ctx->poll_interval)
-	break;
+        break;
     }
 
   return (0);
@@ -629,9 +633,9 @@ _ipmi_kcs_sleep (ipmi_kcs_ctx_t ctx, struct timeval *start)
   else
     {
       if (_ipmi_kcs_spin_sleep (ctx) < 0)
-	return (-1);
+        return (-1);
     }
-  
+
   return (0);
 }
 
@@ -656,7 +660,7 @@ _ipmi_kcs_wait_for_ibf_clear (ipmi_kcs_ctx_t ctx)
   while (_ipmi_kcs_get_status (ctx) & IPMI_KCS_STATUS_REG_IBF)
     {
       if (_ipmi_kcs_sleep (ctx, &start) < 0)
-	return (-1);
+        return (-1);
     }
 
   return (0);
@@ -684,7 +688,7 @@ _ipmi_kcs_wait_for_obf_set (ipmi_kcs_ctx_t ctx)
   while (!(_ipmi_kcs_get_status (ctx) & IPMI_KCS_STATUS_REG_OBF))
     {
       if (_ipmi_kcs_sleep (ctx, &start) < 0)
-	return (-1);
+        return (-1);
     }
 
   return (0);
@@ -867,7 +871,7 @@ ipmi_kcs_write (ipmi_kcs_ctx_t ctx,
       _ipmi_kcs_write_byte (ctx, *p);
 
       if (_ipmi_kcs_wait_for_ibf_clear (ctx) < 0)
-	goto cleanup;
+        goto cleanup;
 
       if (!_ipmi_kcs_test_if_state (ctx, IPMI_KCS_STATE_WRITE))
         {
@@ -904,7 +908,7 @@ ipmi_kcs_write (ipmi_kcs_ctx_t ctx,
       exit (EXIT_FAILURE);
     }
 #endif
-  
+
   if (count > INT_MAX)
     {
       KCS_SET_ERRNUM (ctx, IPMI_KCS_ERR_OVERFLOW);
@@ -963,7 +967,7 @@ ipmi_kcs_read (ipmi_kcs_ctx_t ctx,
     {
       char c;
       if (_ipmi_kcs_wait_for_obf_set (ctx) < 0)
-	goto cleanup;
+        goto cleanup;
       c = _ipmi_kcs_read_byte (ctx);
       if (count < buf_len)
         {
@@ -972,14 +976,14 @@ ipmi_kcs_read (ipmi_kcs_ctx_t ctx,
         }
       _ipmi_kcs_read_next (ctx);
       if (_ipmi_kcs_wait_for_ibf_clear (ctx) < 0)
-	goto cleanup;
+        goto cleanup;
     }
 
   if (_ipmi_kcs_test_if_state (ctx, IPMI_KCS_STATE_IDLE))
     {
       /* Clean up */
       if (_ipmi_kcs_wait_for_obf_set (ctx) < 0)
-	goto cleanup;
+        goto cleanup;
       _ipmi_kcs_read_byte (ctx); /* toss it, ACK */
     }
   else
@@ -1052,8 +1056,6 @@ _ipmi_kcs_cmd_write (ipmi_kcs_ctx_t ctx,
       goto cleanup;
     }
 
-  memset (pkt, 0, pkt_len);
-
   if (fill_hdr_ipmi_kcs (lun,
                          net_fn,
                          obj_hdr) < 0)
@@ -1066,7 +1068,7 @@ _ipmi_kcs_cmd_write (ipmi_kcs_ctx_t ctx,
                              obj_cmd_rq,
                              pkt,
                              pkt_len,
-			     IPMI_INTERFACE_FLAGS_DEFAULT) < 0)
+                             IPMI_INTERFACE_FLAGS_DEFAULT) < 0)
     {
       KCS_SET_ERRNUM (ctx, IPMI_KCS_ERR_INTERNAL_ERROR);
       goto cleanup;
@@ -1128,8 +1130,6 @@ _ipmi_kcs_cmd_read (ipmi_kcs_ctx_t ctx,
       goto cleanup;
     }
 
-  memset (pkt, 0, pkt_len);
-
   if ((read_len = ipmi_kcs_read (ctx,
                                  pkt,
                                  pkt_len)) < 0)
@@ -1145,7 +1145,7 @@ _ipmi_kcs_cmd_read (ipmi_kcs_ctx_t ctx,
                                       read_len,
                                       obj_hdr,
                                       obj_cmd_rs,
-				      IPMI_INTERFACE_FLAGS_DEFAULT)) < 0)
+                                      IPMI_INTERFACE_FLAGS_DEFAULT)) < 0)
     {
       KCS_SET_ERRNUM (ctx, IPMI_KCS_ERR_INTERNAL_ERROR);
       goto cleanup;
