@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2003-2015 FreeIPMI Core Team
- * 
+ *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
@@ -13,7 +13,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- * 
+ *
  */
 
 #ifdef HAVE_CONFIG_H
@@ -207,7 +207,6 @@ ipmi_openipmi_ctx_create (void)
       ERRNO_TRACE (errno);
       return (NULL);
     }
-  memset (ctx, '\0', sizeof (struct ipmi_openipmi_ctx));
 
   ctx->magic = IPMI_OPENIPMI_CTX_MAGIC;
   ctx->flags = IPMI_OPENIPMI_FLAGS_DEFAULT;
@@ -437,7 +436,6 @@ _openipmi_write (ipmi_openipmi_ctx_t ctx,
   /* Due to API differences, we need to extract the cmd out of the
    * request.
    */
-  memset (rq_buf_temp, '\0', IPMI_OPENIPMI_BUFLEN);
 
   if ((len = fiid_obj_get_all (obj_cmd_rq,
                                rq_buf_temp,
@@ -532,27 +530,27 @@ _openipmi_read (ipmi_openipmi_ctx_t ctx,
 
   do {
     if ((n = select (ctx->device_fd + 1,
-		     &read_fds,
-		     NULL,
-		     NULL,
-		     &tv)) < 0)
+                     &read_fds,
+                     NULL,
+                     NULL,
+                     &tv)) < 0)
       {
-	if (errno != EINTR)
-	  {
-	    OPENIPMI_ERRNO_TO_OPENIPMI_ERRNUM (ctx, errno);
-	    return (-1);
-	  }
+        if (errno != EINTR)
+          {
+            OPENIPMI_ERRNO_TO_OPENIPMI_ERRNUM (ctx, errno);
+            return (-1);
+          }
 
-	if (gettimeofday (&end, NULL) < 0)
-	  {
-	    OPENIPMI_ERRNO_TO_OPENIPMI_ERRNUM (ctx, errno);
-	    return (-1);
-	  }
-	
-	/* delta = end - start */
-	timersub (&end, &start, &delta);
-	/* tv = tv_orig - delta */
-	timersub (&tv_orig, &delta, &tv);
+        if (gettimeofday (&end, NULL) < 0)
+          {
+            OPENIPMI_ERRNO_TO_OPENIPMI_ERRNUM (ctx, errno);
+            return (-1);
+          }
+
+        /* delta = end - start */
+        timersub (&end, &start, &delta);
+        /* tv = tv_orig - delta */
+        timersub (&tv_orig, &delta, &tv);
       }
   } while (n < 0);
 
