@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2003-2015 FreeIPMI Core Team
- * 
+ *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
@@ -13,7 +13,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- * 
+ *
  */
 
 #ifdef HAVE_CONFIG_H
@@ -829,7 +829,6 @@ _ipmi_acpi_get_rsdp (ipmi_locate_ctx_t ctx,
       LOCATE_ERRNO_TO_LOCATE_ERRNUM (ctx, errno);
       goto cleanup;
     }
-  memset (memdata, '\0', rsdp_window_size);
 
   if ((acpi_rsdp_descriptor_len = fiid_template_len_bytes (tmpl_acpi_rsdp_descriptor)) < 0)
     {
@@ -937,8 +936,7 @@ _ipmi_acpi_get_rsdp (ipmi_locate_ctx_t ctx,
                 LOCATE_SET_ERRNUM (ctx, IPMI_LOCATE_ERR_OUT_OF_MEMORY);
                 goto cleanup;
               }
-            memset (memdata, '\0', acpi_rsdp_descriptor_len);
-            
+
             if (_ipmi_get_physical_mem_data (ctx,
                                              rsdt_xsdt_address,
                                              acpi_rsdp_descriptor_len,
@@ -1030,13 +1028,13 @@ _ipmi_acpi_get_table (ipmi_locate_ctx_t ctx,
       goto cleanup;
     }
 
-  table_signature_length = len + 1;
-  if (!(table_signature = malloc (table_signature_length)))
+  table_signature_length = len;
+  if (!(table_signature = malloc (table_signature_length + 1)))
     {
       LOCATE_ERRNO_TO_LOCATE_ERRNUM (ctx, errno);
       goto cleanup;
     }
-  memset (table_signature, '\0', table_signature_length);
+  memset (table_signature, '\0', table_signature_length + 1);
 
   if ((acpi_table_hdr_length = fiid_template_len_bytes (tmpl_acpi_table_hdr)) < 0)
     {
@@ -1055,7 +1053,6 @@ _ipmi_acpi_get_table (ipmi_locate_ctx_t ctx,
       LOCATE_ERRNO_TO_LOCATE_ERRNUM (ctx, errno);
       goto cleanup;
     }
-  memset (acpi_table_buf, '\0', acpi_table_hdr_length);
 
   if (_ipmi_get_physical_mem_data (ctx,
                                    table_address,
@@ -1531,7 +1528,7 @@ ipmi_locate_acpi_spmi_get_device_info (ipmi_locate_ctx_t ctx,
 #if 0
   {
     uint8_t ipmi_legacy;
-    
+
     if (FIID_OBJ_GET (obj_acpi_spmi_table_descriptor,
                       tmpl_acpi_spmi_table_descriptor,
                       "ipmi_legacy",
@@ -1541,7 +1538,7 @@ ipmi_locate_acpi_spmi_get_device_info (ipmi_locate_ctx_t ctx,
         goto cleanup;
       }
     ipmi_legacy = val;
-    
+
     if (ipmi_legacy != 1)
       {
         LOCATE_SET_ERRNUM (ctx, IPMI_LOCATE_ERR_SYSTEM_ERROR);
@@ -1562,7 +1559,7 @@ ipmi_locate_acpi_spmi_get_device_info (ipmi_locate_ctx_t ctx,
         goto cleanup;
       }
     ipmi_version_major = val;
-    
+
     if (FIID_OBJ_GET (obj_acpi_spmi_table_descriptor,
                       "specification_revision.minor",
                       &val) < 0)
