@@ -69,6 +69,8 @@
 
 #include "freeipmi-portability.h"
 #include "conffile.h"
+#include "fi_hostlist.h"
+#include "network.h"
 #include "parse-common.h"
 #include "secure.h"
 
@@ -147,7 +149,7 @@ _config_file_unsigned_int_positive (conffile_t cf,
   assert (option_ptr);
 
   value = (unsigned int *)option_ptr;
-  
+
   if (data->intval <= 0)
     {
       IPMICONSOLE_DEBUG (("libipmiconsole config file %s invalid", optionname));
@@ -208,19 +210,19 @@ _config_file_password (conffile_t cf,
 
 static int
 _config_file_k_g (conffile_t cf,
-                       struct conffile_data *data,
-                       char *optionname,
-                       int option_type,
-                       void *option_ptr,
-                       int option_data,
-                       void *app_ptr,
-                       int app_data)
+                  struct conffile_data *data,
+                  char *optionname,
+                  int option_type,
+                  void *option_ptr,
+                  int option_data,
+                  void *app_ptr,
+                  int app_data)
 {
   int rv;
 
   assert (data);
 
-  if ((rv = parse_kg (default_config.k_g, IPMI_MAX_K_G_LENGTH + 1, data->string)) < 0)
+  if ((rv = parse_kg (default_config.k_g, IPMI_MAX_K_G_LENGTH, data->string)) < 0)
     {
       IPMICONSOLE_DEBUG (("libipmiconsole config file k_g invalid format"));
       return (0);
@@ -309,7 +311,7 @@ _config_file_workaround_flags (conffile_t cf,
                                   NULL,
                                   &outofband_2_0_flags,
                                   NULL,
-				  NULL,
+                                  NULL,
                                   &section_flags) < 0)
         {
           IPMICONSOLE_DEBUG (("libipmiconsole config file workaround flag invalid"));
@@ -418,7 +420,7 @@ _config_file_behavior_flags (conffile_t cf,
     }
 
   default_config.behavior_flags = behavior_flags;
-  
+
   IPMICONSOLE_DEBUG (("libipmiconsole loaded alternate default behavior flag"));
   return (0);
 }
@@ -462,13 +464,13 @@ _config_file_debug_flags (conffile_t cf,
 
 static int
 _config_file_sol_payload_instance (conffile_t cf,
-				   struct conffile_data *data,
-				   char *optionname,
-				   int option_type,
-				   void *option_ptr,
-				   int option_data,
-				   void *app_ptr,
-				   int app_data)
+                                   struct conffile_data *data,
+                                   char *optionname,
+                                   int option_type,
+                                   void *option_ptr,
+                                   int option_data,
+                                   void *app_ptr,
+                                   int app_data)
 {
   unsigned int *value;
 
@@ -476,7 +478,7 @@ _config_file_sol_payload_instance (conffile_t cf,
   assert (option_ptr);
 
   value = (unsigned int *)option_ptr;
-  
+
   if (data->intval <= 0
       || !IPMI_PAYLOAD_INSTANCE_VALID (data->intval))
     {
@@ -689,7 +691,7 @@ _ipmiconsole_defaults_setup (void)
         "libipmiconsole-context-sol-payload-instance",
         CONFFILE_OPTION_INT,
         -1,
-	_config_file_sol_payload_instance,
+        _config_file_sol_payload_instance,
         1,
         0,
         &libipmiconsole_context_sol_payload_instance_count,
@@ -733,18 +735,18 @@ _ipmiconsole_defaults_setup (void)
                       0) < 0)
     {
       char buf[CONFFILE_MAX_ERRMSGLEN];
-      
+
       /* Its not an error if the default configuration file doesn't exist */
       if (conffile_errnum (cf) == CONFFILE_ERR_EXIST)
         goto out;
-      
+
       if (conffile_errmsg (cf, buf, CONFFILE_MAX_ERRMSGLEN) < 0)
         {
           IPMICONSOLE_DEBUG (("libipmiconsole loaded alternate default debug flag"));
           goto cleanup;
         }
     }
-  
+
  out:
   rv = 0;
  cleanup:
@@ -760,7 +762,7 @@ ipmiconsole_engine_init (unsigned int thread_count, unsigned int debug_flags)
 
   if (thread_count > IPMICONSOLE_THREAD_COUNT_MAX
       || (debug_flags != IPMICONSOLE_DEBUG_DEFAULT
-	  && debug_flags & ~IPMICONSOLE_DEBUG_MASK))
+          && debug_flags & ~IPMICONSOLE_DEBUG_MASK))
     {
       errno = EINVAL;
       return (-1);
@@ -836,10 +838,13 @@ ipmiconsole_engine_submit (ipmiconsole_ctx_t c,
                                           callback_arg) < 0)
     goto cleanup;
 
-  if (ipmiconsole_ctx_connection_setup (c) < 0)
+  /* session setup required before connection setup, so
+   * connection knows if IPv4 or IPv6 used
+   */
+  if (ipmiconsole_ctx_session_setup (c) < 0)
     goto cleanup;
 
-  if (ipmiconsole_ctx_session_setup (c) < 0)
+  if (ipmiconsole_ctx_connection_setup (c) < 0)
     goto cleanup;
 
   if (ipmiconsole_engine_submit_ctx (c) < 0)
@@ -1068,10 +1073,13 @@ ipmiconsole_engine_submit_block (ipmiconsole_ctx_t c)
   /* Set to success, so we know if an IPMI error occurred later */
   ipmiconsole_ctx_set_errnum (c, IPMICONSOLE_ERR_SUCCESS);
 
-  if (ipmiconsole_ctx_connection_setup (c) < 0)
+  /* session setup required before connection setup, so
+   * connection knows if IPv4 or IPv6 used
+   */
+  if (ipmiconsole_ctx_session_setup (c) < 0)
     goto cleanup;
 
-  if (ipmiconsole_ctx_session_setup (c) < 0)
+  if (ipmiconsole_ctx_connection_setup (c) < 0)
     goto cleanup;
 
   if (_ipmiconsole_blocking_notification_setup (c) < 0)
@@ -1153,9 +1161,12 @@ ipmiconsole_ctx_create (const char *hostname,
                         struct ipmiconsole_engine_config *engine_config)
 {
   ipmiconsole_ctx_t c = NULL;
-  char hostnamebuf[MAXHOSTNAMELEN_WITH_PORT + 1];
-  char *hostname_ptr;
+  char *hostname_copy = NULL;
+  char *port_copy = NULL;
+  const char *hostname_ptr = NULL;
+  const char *port_ptr = NULL;
   uint16_t port = RMCP_PRIMARY_RMCP_PORT;
+  int ret;
 
   if (!hostname
       || !ipmi_config
@@ -1171,75 +1182,51 @@ ipmiconsole_ctx_create (const char *hostname,
       || (ipmi_config->cipher_suite_id >= IPMI_CIPHER_SUITE_ID_MIN
           && !IPMI_CIPHER_SUITE_ID_SUPPORTED (ipmi_config->cipher_suite_id))
       || (ipmi_config->workaround_flags != IPMICONSOLE_WORKAROUND_DEFAULT
-	  && ipmi_config->workaround_flags & ~IPMICONSOLE_WORKAROUND_MASK)
+          && ipmi_config->workaround_flags & ~IPMICONSOLE_WORKAROUND_MASK)
       || (engine_config->engine_flags != IPMICONSOLE_ENGINE_DEFAULT
-	  && engine_config->engine_flags & ~IPMICONSOLE_ENGINE_MASK)
+          && engine_config->engine_flags & ~IPMICONSOLE_ENGINE_MASK)
       || (engine_config->behavior_flags != IPMICONSOLE_BEHAVIOR_DEFAULT
-	  && engine_config->behavior_flags & ~IPMICONSOLE_BEHAVIOR_MASK)
+          && engine_config->behavior_flags & ~IPMICONSOLE_BEHAVIOR_MASK)
       || (engine_config->debug_flags != IPMICONSOLE_DEBUG_DEFAULT
-	  && engine_config->debug_flags & ~IPMICONSOLE_DEBUG_MASK))
+          && engine_config->debug_flags & ~IPMICONSOLE_DEBUG_MASK))
     {
       IPMICONSOLE_DEBUG (("invalid input parameters"));
       errno = EINVAL;
       return (NULL);
     }
 
-  if (strchr (hostname, ':'))
+  /* Check for host:port or [Ipv6]:port format */
+  if ((ret = host_is_host_with_port (hostname,
+                                     &hostname_copy,
+                                     &port_copy)) < 0)
     {
-      char *ptr;
+      IPMICONSOLE_DEBUG (("host_is_host_with_port: %s", errno));
+      errno = EINVAL;
+      return (NULL);
+    }
 
-      if (strlen (hostname) > MAXHOSTNAMELEN_WITH_PORT)
-	{
-	  IPMICONSOLE_DEBUG (("invalid input parameters"));
-	  errno = EINVAL;
-	  return (NULL);
-	} 
-      
-      memset (hostnamebuf, '\0', MAXHOSTNAMELEN_WITH_PORT + 1);
-      strcpy (hostnamebuf, hostname);
-      
-      if ((ptr = strchr (hostnamebuf, ':')))
-	{
-	  char *endptr;
-          int tmp;
-	  
-	  *ptr = '\0';
-	  ptr++;
-	  
-	  if (strlen (hostnamebuf) > MAXHOSTNAMELEN)
-	    {
-	      IPMICONSOLE_DEBUG (("invalid input parameters"));
-	      errno = EINVAL;
-	      return (NULL);
-	    } 
-	  
-	  errno = 0;
-	  tmp = strtol (ptr, &endptr, 0);
-	  if (errno
-              || endptr[0] != '\0'
-              || tmp <= 0
-	      || tmp > USHRT_MAX)
-	    {
-	      IPMICONSOLE_DEBUG (("invalid input parameters"));
-	      errno = EINVAL;
-	      return (NULL);
-	    }
-	  
-	  port = tmp;
-	}
-
-      hostname_ptr = hostnamebuf;
+  if (ret)
+    {
+      hostname_ptr = hostname_copy;
+      port_ptr = port_copy;
     }
   else
-    {
-      if (strlen (hostname) > MAXHOSTNAMELEN)
-	{
-	  IPMICONSOLE_DEBUG (("invalid input parameters"));
-	  errno = EINVAL;
-	  return (NULL);
-	}
+    hostname_ptr = hostname;
 
-      hostname_ptr = (char *)hostname;
+  if ((ret = host_is_valid (hostname_ptr,
+                            port_ptr,
+                            &port)) < 0)
+    {
+      IPMICONSOLE_DEBUG (("host_is_valid: %s", errno));
+      errno = EINVAL;
+      goto free_cleanup;
+    }
+
+  if (!ret)
+    {
+      IPMICONSOLE_DEBUG (("invalid input parameters"));
+      errno = EINVAL;
+      goto free_cleanup;
     }
 
   /* If engine is not setup, the default_config is not yet known */
@@ -1247,7 +1234,7 @@ ipmiconsole_ctx_create (const char *hostname,
     {
       IPMICONSOLE_DEBUG (("engine not initialized"));
       errno = EAGAIN;
-      return (NULL);
+      goto free_cleanup;
     }
 
   if ((engine_config->engine_flags != IPMICONSOLE_ENGINE_DEFAULT
@@ -1257,7 +1244,7 @@ ipmiconsole_ctx_create (const char *hostname,
       if (!(c = (ipmiconsole_ctx_t)secure_malloc (sizeof (struct ipmiconsole_ctx))))
         {
           errno = ENOMEM;
-          return (NULL);
+          goto free_cleanup;
         }
     }
   else
@@ -1265,7 +1252,7 @@ ipmiconsole_ctx_create (const char *hostname,
       if (!(c = (ipmiconsole_ctx_t)malloc (sizeof (struct ipmiconsole_ctx))))
         {
           errno = ENOMEM;
-          return (NULL);
+          goto free_cleanup;
         }
     }
 
@@ -1278,7 +1265,7 @@ ipmiconsole_ctx_create (const char *hostname,
 
   if (ipmiconsole_ctx_config_setup (c,
                                     hostname_ptr,
-				    port,
+                                    port,
                                     ipmi_config,
                                     protocol_config,
                                     engine_config) < 0)
@@ -1299,6 +1286,9 @@ ipmiconsole_ctx_create (const char *hostname,
 
   c->session_submitted = 0;
 
+  free (hostname_copy);
+  free (port_copy);
+
   ipmiconsole_ctx_set_errnum (c, IPMICONSOLE_ERR_SUCCESS);
   return (c);
 
@@ -1321,13 +1311,19 @@ ipmiconsole_ctx_create (const char *hostname,
     secure_free (c, sizeof (struct ipmiconsole_ctx));
   else
     free (c);
+
+ free_cleanup:
+
+  free (hostname_copy);
+  free (port_copy);
+
   return (NULL);
 }
 
 int
 ipmiconsole_ctx_set_config (ipmiconsole_ctx_t c,
-			    ipmiconsole_ctx_config_option_t config_option,
-			    void *config_option_value)
+                            ipmiconsole_ctx_config_option_t config_option,
+                            void *config_option_value)
 {
   unsigned int *tmpptr;
 
@@ -1354,10 +1350,10 @@ ipmiconsole_ctx_set_config (ipmiconsole_ctx_t c,
     case IPMICONSOLE_CTX_CONFIG_OPTION_SOL_PAYLOAD_INSTANCE:
       tmpptr = (unsigned int *)config_option_value;
       if (!IPMI_PAYLOAD_INSTANCE_VALID((*tmpptr)))
-	{
-	  ipmiconsole_ctx_set_errnum (c, IPMICONSOLE_ERR_PARAMETERS);
-	  return (-1);
-	}
+        {
+          ipmiconsole_ctx_set_errnum (c, IPMICONSOLE_ERR_PARAMETERS);
+          return (-1);
+        }
       c->config.sol_payload_instance = *(tmpptr);
       break;
     default:
@@ -1371,8 +1367,8 @@ ipmiconsole_ctx_set_config (ipmiconsole_ctx_t c,
 
 int
 ipmiconsole_ctx_get_config (ipmiconsole_ctx_t c,
-			    ipmiconsole_ctx_config_option_t config_option,
-			    void *config_option_value)
+                            ipmiconsole_ctx_config_option_t config_option,
+                            void *config_option_value)
 {
   unsigned int *tmpptr;
 
